elephant.current_source_density_src.basis_functions module — Elephant 0.5.0 documentation

# elephant.current_source_density_src.basis_functions module

This script is used to generate basis sources for the kCSD method Jan et.al (2012) for 1D,2D and 3D cases. Two ‘types’ are described here, gaussian and step source, These can be easily extended. These scripts are based on Grzegorz Parka’s, Google Summer of Code 2014, INFC/pykCSD This was written by : Michal Czerwinski, Chaitanya Chintaluri Laboratory of Neuroinformatics, Nencki Institute of Experimental Biology, Warsaw.

`elephant.current_source_density_src.basis_functions.` `gauss`(d, stdev, dim)

  Gaussian function Parameters ———- d : floats or np.arrays

  > Distance array to the point of evaluation

  stdev : float
    cutoff range
  dim : int
    dimension of the gaussian function
  Z : floats or np.arrays
    function evaluated

`elephant.current_source_density_src.basis_functions.` `gauss_1D`(d, three_stdev)

  Returns normalized gaussian 2D scale function Parameters ———- d : floats or np.arrays

  > Distance array to the point of evaluation

  three_stdev : float
    3 * standard deviation of the distribution

  Z : (three_std/3)*(1/2*pi)*(exp(-0.5)*stddev**(-2) *(d**2))

`elephant.current_source_density_src.basis_functions.` `gauss_2D`(d, three_stdev)

  Returns normalized gaussian 2D scale function Parameters ———- d : floats or np.arrays

  > distance at which we need the function evaluated

  three_stdev : float
    3 * standard deviation of the distribution
  Z : function
    Normalized gaussian 2D function

`elephant.current_source_density_src.basis_functions.` `gauss_3D`(d, three_stdev)

  Returns normalized gaussian 3D scale function Parameters ———- d : floats or np.arrays

  > distance at which we need the function evaluated

  three_stdev : float
    3 * standard deviation of the distribution
  Z : funtion
    Normalized gaussian 3D function

`elephant.current_source_density_src.basis_functions.` `gauss_lim_1D`(d, three_stdev)

  Returns gausian 2D function cut off after 3 standard deviations. Parameters ———- d : floats or np.arrays

  > Distance array to the point of evaluation

  three_stdev : float
    3 * standard deviation of the distribution
  Z : (three_std/3)*(1/2*pi)*(exp(-0.5)*stddev**(-2) *((x-mu)**2)),
    cut off = three_stdev

`elephant.current_source_density_src.basis_functions.` `gauss_lim_2D`(d, three_stdev)

  Returns gausian 2D function cut off after 3 standard deviations. Parameters ———- d : floats or np.arrays

  > distance at which we need the function evaluated

  three_stdev : float
    3 * standard deviation of the distribution
  Z : function
    Normalized gaussian 2D function cut off after three_stdev

`elephant.current_source_density_src.basis_functions.` `gauss_lim_3D`(d, three_stdev)

  Returns normalized gaussian 3D scale function cut off after 3stdev Parameters ———- d : floats or np.arrays

  > distance at which we need the function evaluated

  three_stdev : float
    3 * standard deviation of the distribution
  Z : funtion
    Normalized gaussian 3D function cutoff three_Stdev

`elephant.current_source_density_src.basis_functions.` `step_1D`(d, R)

  Returns normalized 1D step function. Parameters ———- d : floats or np.arrays

  > Distance array to the point of evaluation

  R : float
    cutoff range

  s : Value of the function (d <= R) / R

`elephant.current_source_density_src.basis_functions.` `step_2D`(d, R)

  Returns normalized 2D step function. Parameters ———- d : float or np.arrays

  > Distance array to the point of evaluation

  R : float
    cutoff range

  Returns: | s : step function

`elephant.current_source_density_src.basis_functions.` `step_3D`(d, R)

  Returns normalized 3D step function. Parameters ———- d : floats or np.arrays

  > distance at which we need the function evaluated

  R : float
    cutoff range

  s : step function in 3D